pub enum ContractAction {
List,
Show,
Validate,
Diff,
ExplainLink,
}Expand description
Contract operation requested by a delivery adapter.
Variants
List
List contract nodes in stable order.
Show
Show one contract and its directly observed relationships.
Validate
Validate graph and evidence integrity for all or one contract.
Diff
Compare two contract nodes and surface supplied compatibility analysis.
ExplainLink
Explain direct links between two contract nodes.