pub enum DeliverySemantics {
AtMostOnce,
AtLeastOnce,
ExactlyOnce,
BestEffort,
}Expand description
Delivery guarantee explicitly stated by a contract or source call.
Variants
AtMostOnce
A message may be lost but is not intentionally redelivered.
AtLeastOnce
A message may be redelivered until it is acknowledged.
ExactlyOnce
The declaration explicitly claims exactly-once processing or delivery.
BestEffort
The declaration explicitly describes best-effort delivery.