pub enum EventRole {
Publisher,
Subscriber,
Declaration,
}Expand description
Repository role represented by an event observation.
Variants
Publisher
Code or a contract sends events to a channel.
Subscriber
Code or a contract receives events from a channel.
Declaration
A channel is declared without an associated send or receive operation.