pub enum ExecutionResource {
WallTimeMs,
NoProgressTimeMs,
WorkerMemoryBytes,
WorkUnits,
WorkerProcess,
WorkerProtocolBytes,
Cancellation,
}Expand description
Resource exhausted by one supervised workspace operation.
Variants
WallTimeMs
Absolute wall time.
NoProgressTimeMs
Time without verified forward progress.
WorkerMemoryBytes
Resident worker memory.
WorkUnits
Deterministic work accounting overflow.
WorkerProcess
The worker terminated without a valid final protocol message.
WorkerProtocolBytes
The worker protocol exceeded its byte limit or was malformed.
Cancellation
The operator or hosting agent requested cancellation.