pub enum LocalEnrichmentStatus {
Available,
Partial,
Stale,
Unavailable,
}Expand description
Availability state of optional repository-local enrichment.
Variants
Available
The local provider completed with current inputs.
Partial
The local provider returned only part of the requested result.
Stale
The local index does not match current repository inputs.
The local capability or repository index is unavailable.