pub enum ManualLinkError {
InvalidDeclaration(ManifestError),
MissingEndpoint {
index: usize,
endpoint: ManualLinkEndpoint,
value: String,
},
AmbiguousEndpoint {
index: usize,
endpoint: ManualLinkEndpoint,
value: String,
candidates: Vec<NodeId>,
},
ResolvedSelfLink {
index: usize,
node: String,
},
DuplicateResolvedLink {
first: usize,
duplicate: usize,
source_node: NodeId,
target_node: NodeId,
relation: EdgeKind,
},
MissingSuppressionTarget {
index: usize,
source_node: NodeId,
target_node: NodeId,
relation: EdgeKind,
},
}Expand description
Error returned while resolving exact manual relationships.
Variants
InvalidDeclaration(ManifestError)
A manually constructed declaration violates manifest invariants.
MissingEndpoint
No node has the exact requested identifier or stable key.
Fields

endpoint: ManualLinkEndpointEndpoint field.
AmbiguousEndpoint
More than one node has the exact requested identifier or stable key.
Fields

endpoint: ManualLinkEndpointEndpoint field.
ResolvedSelfLink
Distinct endpoint literals resolved to the same node.
DuplicateResolvedLink
Distinct declarations resolved to the same graph relationship.
Fields
MissingSuppressionTarget
A suppression did not identify an existing exact automatic relationship.