pub enum MappingCompleteness {
Complete,
Partial,
Unknown,
}Expand description
Explicit completeness of one changed-file semantic mapping.
Variants
Complete
Exact path and hunk evidence reached at least one boundary node.
Partial
Useful path, evidence, or graph mapping exists but is not sufficient to prove completeness.
Unknown
The native path or required persisted evidence could not be mapped.