#[non_exhaustive]pub enum PackageManifestError {
UnsupportedPath(String),
Malformed {
path: String,
message: String,
},
LimitExceeded(ExtractionLimitExceeded),
}Expand description
Failure to recognize or safely parse a package manifest.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedPath(String)
The supplied path is not a supported repository-relative package manifest path.
Malformed
A supported structured file is malformed or contains an invalid static declaration.
LimitExceeded(ExtractionLimitExceeded)
Extraction exceeded one configured invocation resource.