pub enum SourceEpistemicStatus {
Confirmed,
Ambiguous,
Incomplete,
}Expand description
Epistemic state of a source observation.
Variants
Confirmed
Method and path, when applicable, are supported by exact literal syntax.
Ambiguous
A relevant framework operation was found, but a dynamic expression prevents exact identity.
Incomplete
Required method, path, or symbol evidence was absent.