documents_to_graph

Function documents_to_graph 

pub fn documents_to_graph(
    data_inputs: &[(&RepoId, &str, &str, &DataDocument)],
    infrastructure_inputs: &[(&RepoId, &str, &str, &InfrastructureDocument)],
    documentation_inputs: &[(&RepoId, &str, &str, &DocumentationDocument)],
    config_inputs: &[(&RepoId, &str, &str, &SafeConfigDocument)],
    known_nodes: &[Node],
    repository_aliases: &[(&str, &RepoId)],
) -> ExtractionGraphFacts
Converts all supported extractor outputs into deterministic, ambiguity-safe graph facts.

Only exact, unique targets are linked. Dynamic or incomplete observations that lack a concrete target remain unlinked, and retained evidence contains locators and static notes rather than source or configuration values.