pub fn plan_incremental_scan(
previous: &[ArtifactFingerprint],
current: &[ArtifactFingerprint],
) -> IncrementalPlanExpand description
Compares current artifact fingerprints with the previous published snapshot.
pub fn plan_incremental_scan(
previous: &[ArtifactFingerprint],
current: &[ArtifactFingerprint],
) -> IncrementalPlanCompares current artifact fingerprints with the previous published snapshot.