pub struct ChangeSet {Show 17 fields
pub repo_id: RepoId,
pub checkout_id: CheckoutId,
pub worktree: NativePath,
pub git_common_dir: NativePath,
pub scope: ChangeScope,
pub checkout_head_ref: Option<String>,
pub checkout_head_sha: String,
pub base_ref: Option<String>,
pub head_ref: Option<String>,
pub head_sha: String,
pub staged_hash: String,
pub worktree_hash: String,
pub exact_diff_fingerprint: String,
pub workspace_manifest_hash: String,
pub contract_registry_hash: String,
pub analyzer_versions: AnalyzerVersions,
pub files: Vec<ChangedFile>,
}Expand description
Immutable, fingerprinted description of a repository change.
Fields
repo_id: RepoIdStable registered repository identity.
checkout_id: CheckoutIdStable concrete checkout identity.
worktree: NativePathCanonical, lossless worktree root.
git_common_dir: NativePathCanonical, lossless common Git directory.
scope: ChangeScopeRequested scope.
checkout_head_ref: Option<String>Symbolic checkout HEAD, when attached.
checkout_head_sha: StringCommit currently checked out before applying the requested scope.
base_ref: Option<String>Scope base ref or object ID, when applicable.
head_ref: Option<String>Scope head ref or object ID, when applicable.
head_sha: StringResolved commit for the scope head.
staged_hash: StringBLAKE3 hash of exact bounded staged Git output.
worktree_hash: StringBLAKE3 hash of exact bounded tracked and untracked worktree output.
exact_diff_fingerprint: StringBLAKE3 fingerprint of exact bounded Git output and identity metadata.
workspace_manifest_hash: StringWorkspace manifest fingerprint used by analysis.
contract_registry_hash: StringContract registry fingerprint used by analysis.
analyzer_versions: AnalyzerVersionsAnalyzer names and exact versions used by analysis.
files: Vec<ChangedFile>Deterministically ordered changed files.