pub struct ContractRequest {
pub action: ContractAction,
pub contract: Option<NodeId>,
pub related_contract: Option<NodeId>,
pub limit: usize,
}Expand description
Bounded input for one contract application operation.
Fields
action: ContractActionRequested operation.
contract: Option<NodeId>Primary contract for show, targeted validate, diff, or explain-link.
Comparison or link endpoint required by diff and explain-link.
limit: usizeMaximum number of contracts or links returned.