pub struct GitCliChangeProvider { /* private fields */ }Expand description
Configuration for the production local Git provider.
Implementations
Sourceimpl GitCliChangeProvider
impl GitCliChangeProvider
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a provider using git from the process search path and conservative budgets.
Sourcepub fn with_limits(
git_binary: impl Into<OsString>,
timeout: Duration,
stdout_cap: usize,
stderr_cap: usize,
) -> Self
pub fn with_limits( git_binary: impl Into<OsString>, timeout: Duration, stdout_cap: usize, stderr_cap: usize, ) -> Self
Creates a provider with explicit executable and process budgets.
Zero output limits are rejected when ChangeProvider::changes is called.