pub struct GraphqlPersistedOperation {
pub id: String,
pub operation_name: Option<String>,
pub kind: Option<GraphqlOperationKind>,
pub consumed_field_paths: Vec<String>,
pub complete: bool,
pub warnings: Vec<String>,
pub source_path: String,
pub lines: GraphqlLineRange,
}Expand description
Persisted operation manifest entry without the persisted query body.
Fields
id: StringPersisted operation identifier or hash.
operation_name: Option<String>Declared or parsed operation name.
kind: Option<GraphqlOperationKind>Parsed operation category, when a literal document is available.
consumed_field_paths: Vec<String>Deterministically sorted consumed field paths.
complete: boolWhether a literal operation document was parsed successfully.
warnings: Vec<String>Machine-readable limitations for this entry.
source_path: StringSource manifest path.
lines: GraphqlLineRangeSource evidence for the manifest entry.