pub struct HunkLineMatch {
pub evidence_id: EvidenceId,
pub path_side: ChangedPathSide,
pub kind: EvidenceMatchKind,
pub hunk_index: Option<usize>,
pub hunk_start: Option<u32>,
pub hunk_end: Option<u32>,
pub evidence_start: Option<u32>,
pub evidence_end: Option<u32>,
}Expand description
Position-only explanation of why evidence matched a changed file.
Fields
evidence_id: EvidenceIdMatched persisted evidence.
path_side: ChangedPathSideOld or new path and hunk side used by the match.
kind: EvidenceMatchKindMatch strength.
hunk_index: Option<usize>Zero-based hunk index for an exact line intersection.
hunk_start: Option<u32>Inclusive changed-hunk start line.
hunk_end: Option<u32>Inclusive changed-hunk end line.
evidence_start: Option<u32>Inclusive persisted-evidence start line.
evidence_end: Option<u32>Inclusive persisted-evidence end line.