pub struct ProviderRequest {
pub repo_id: RepoId,
pub project_path: PathBuf,
pub budget: ProviderBudget,
pub cancellation: CancellationToken,
}Expand description
Repository scope and controls shared by all provider requests.
Fields
repo_id: RepoIdStable repository identity.
project_path: PathBufNative absolute checkout path passed directly to the child process.
budget: ProviderBudgetExplicit execution limits.
cancellation: CancellationTokenCooperative cancellation signal.