pub struct RegisteredWorkspace {
pub record: WorkspaceRecord,
/* private fields */
}Expand description
Validated workspace record plus native paths used by scanners.
Fields
record: WorkspaceRecordSerializable registry record suitable for persistence.
Implementations
Sourceimpl RegisteredWorkspace
impl RegisteredWorkspace
Sourcepub fn checkout_path(&self, alias: &str) -> Option<&Path>
pub fn checkout_path(&self, alias: &str) -> Option<&Path>
Returns the canonical checkout path for a registered alias.