pub struct SourceSyntaxInspection {
pub has_error: bool,
pub boundary_candidate_count: usize,
}Expand description
Bounded syntax inspection used to corroborate focused textual facts.
Fields
has_error: boolWhether Tree-sitter recovered from at least one syntax error.
boundary_candidate_count: usizeNumber of syntax nodes that can contain a supported boundary.