pub enum SourceFramework {
Show 29 variants
Fetch,
Axios,
Express,
Fastify,
NestJs,
NextJs,
Axum,
ActixWeb,
Utoipa,
Reqwest,
RustTest,
TokioTest,
Rstest,
FastApi,
Flask,
Requests,
Httpx,
AioHttp,
PythonHttpRegistry,
FactoryBoy,
Pytest,
Unittest,
PythonTest,
GoNetHttp,
Gin,
Chi,
SpringMvc,
WebClient,
Feign,
}Expand description
Framework whose syntax supplied the direct evidence.
Variants
Fetch
Browser or runtime Fetch API calls.
Axios
Axios HTTP client calls.
Express
Express route declarations.
Fastify
Fastify route declarations.
NestJs
NestJS controller declarations.
NextJs
Next.js App Router file-route declarations.
Axum
Axum router declarations.
ActixWeb
Actix Web route declarations and route attributes.
Utoipa
Utoipa operation declarations, including Actix routes wrapped by cfg_attr.
Reqwest
Reqwest client calls.
RustTest
Rust built-in #[test] functions.
TokioTest
Tokio #[tokio::test] functions.
Rstest
Rstest #[rstest] functions.
FastApi
FastAPI route decorators.
Flask
Flask route decorators.
Requests
Python requests calls.
Httpx
Python HTTPX calls.
AioHttp
Python aiohttp client-session calls.
PythonHttpRegistry
Statically declared Python HTTP method/path registries.
FactoryBoy
Factory Boy model and sub-factory declarations.
Pytest
Pytest test functions.
Unittest
unittest TestCase methods.
PythonTest
Canonical test_ methods in a Python class whose runner inheritance is resolved elsewhere.
GoNetHttp
Go standard-library net/http.
Gin
Gin route declarations.
Chi
Chi route declarations.
SpringMvc
Spring MVC route declarations.
WebClient
Spring WebClient calls.
Feign
Feign client declarations.